#
# spec file for package xournalpp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xournalpp
Version:        1.2.6
Release:        1.2
Summary:        Notetaking software designed around a tablet
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://github.com/xournalpp/xournalpp
Source0:        https://github.com/xournalpp/xournalpp/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM xournalpp-return.patch -- Fix control reaches end of non-void function
Patch0:         xournalpp-return.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  texlive-latex-bin
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(portaudiocpp)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)
Recommends:     webp-pixbuf-loader
Recommends:     tex(scontents.tex)
Recommends:     tex(standalone.tex)
%if 0%{?suse_version} < 1550
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc-c++
%endif

%description
Xournal++ is a hand note taking software.
It supports pen input, e.g. Wacom tablets.

%lang_package

%prep
%autosetup -p1

%build
%cmake -DENABLE_MATHTEX=ON \
%if 0%{?suse_version} < 1550
       -DCMAKE_CXX_COMPILER="%{_bindir}/g++-9" \
%endif
       %{nil}
%cmake_build

%install
%cmake_install
%find_lang xournalpp %{no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/xournalpp-thumbnailer
%{_bindir}/xournalpp
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/scalable/mimetypes/*.svg
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/mime/packages/*.xml
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/*.thumbnailer
%{_datadir}/xournalpp/

%files lang -f xournalpp.lang

%changelog
* Thu Feb 20 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.6:
  * Fixed compass outline drawing.
  * Exposed selected text to the windowing system.
* Sun Dec 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.5:
  * Fixed regressions when exporting to PDF.
  * Fixed crash when importing some SVG files.
  * Have geometry tools appear in the middle of the view.
  * Updated translations.
* Fri Oct 25 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.4:
  * Fixed various dark/light theme inconsistencies.
  * Improved edge panning for large selections.
  * Fixed various crashes, freezes and memory leaks.
- Drop BuildRequires: update-desktop-files since
  %%suse_update_desktop_file macro is no longer used.
* Sat Mar  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.3:
  * Fixed background color and truncated text in LaTeX tool
  * Fixed zoom jumping and zoom steps
  * Fixed various segfaults and rendering issues
  * Fixed pressure values and project URL when saving documents
  * Enabled font hint metrics in PDF export to improve text
    alignment
* Fri Oct 20 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.2:
  * Fixed various memory leaks and segmentation faults.
  * Fixed some issues with input sequences mixing up devices and
    buttons.
  * Fixed LaTeX tool failing to open some PDF files.
  * Fixed audio output device selection.
* Fri Aug 25 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.1:
  * Added a default toolbar so that the app does not start without
    toolbar on new installations
  * Fixed some crashes and various issues with the crash log
    handling
  * Added options to the command line and preferences to disable
    the audio system used for audio recording
  * The official release builds are now all built with
    gtksourceview styling for the LaTeX tool and in "RelWithDeb"
    mode. Thus failing asserts do not result in a crash anymore.
* Wed Aug  2 2023 thod_@gmx.de
- update to 1.2.0:
  * Added PDF text selection tools
  * Added Setsquare Tool and Compass Tool
  * Many more changes; for the full list, see
    https://github.com/xournalpp/xournalpp/blob/release-1.2/CHANGELOG.md
- remove xournalpp-include.patch, fixed upstream
- Add xournalpp-return.patch: Fix control reaches end of non-void function
* Wed Apr 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add xournalpp-include.patch: Add missing include exposed by
  gcc-13.
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.3:
  * Fixed a crash that occurs when trying to add/edit/test LaTeX if LaTeX is
    not found
  * Fixed a crash that could occur when quitting when using a touchscreen
    device
  * Fixed a bug that closed text fields immediately after creating them with
    a secondary mouse or stylus button
  * Added a setting in the preferences to disable Gtk inertial scrolling,
    avoiding weird scrolling on some devices
  * Linux: added an Ubuntu 22.04 release build
* Wed Nov  2 2022 Fabio Pesari <fpesari@tuxfamily.org>
- Updated to version 1.1.2:
  * Fix assertion on selection existence
  * Fix PDF toolbox showing at the wrong position on Wayland
  * Minimum size for shape recognizer now
  customizable (gh#xournalpp/xournalpp#4283)
* Mon Oct 17 2022 Michael Vetter <mvetter@suse.com>
- Add Recommends webp-pixbuf-loader:
  See https://github.com/xournalpp/xournalpp/issues/4248
* Tue Feb 22 2022 postix@posteo.eu
- Add Recommends tex(scontents.tex) :
  Required for LaTeX rendering using Xournalpp's default_template.tex
* Mon Feb 14 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.1.1:
  * Change the edge panning behavior when an element is selected,
    fixing the absurdly fast edge pan speed bug.
  * Fixed several crashing/freezing issues.
  * Fixed several bugs involving stroke input and rendering.
  * Fixed several bugs involving PDF rendering (in application) and export.
  * lots of bug fixes; for the full list, see
    https://github.com/xournalpp/xournalpp/blob/v1.1.1/CHANGELOG.md
* Wed Aug  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.1.0:
  * Major release with many changes, see
    https://github.com/xournalpp/xournalpp/blob/1.1.0/CHANGELOG.md
- Drop xournalpp-fix-desktop-categories.patch: No longer needed.
- Force GCC 9 as the compiler for openSUSE Leap 15.x as builds
  require that as a minimum for proper c++17 support.
- Drop update-icon-cache.sh removal, no longer installed by
  upstream.
- Update BuildRequires with upstream.
* Tue Feb 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add BuildRequires(lua) to enable building plugins.
* Fri Dec 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.20:
  * Fixed a regression with pdf files that could not be
    overwritten (gh#xournalpp/xournalpp#2355).
  * Fixed page layout update after inserting or deleting a page,
    changing the page layout or zooming
    (gh#xournalpp/xournalpp#1777, gh#xournalpp/xournalpp#2346,
    gh#xournalpp/xournalpp#2442).
  * Fixed incorrect rendering of pages after changing the page
    format (gh#xournalpp/xournalpp#2457).
  * Fixed blocked scrolling after saving a file
    (gh#xournalpp/xournalpp#2062).
  * Fixed presentation mode after startup
    (gh#xournalpp/xournalpp#2413).
* Wed Nov 25 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 1.0.19:
  * Changed select object algorithm to be more intuitive
  * Added ability for taps with Select Rectangle and Select Region
    to act like Select Object (gh#xournalpp/xournalpp#1980).
  * Improved document loading speed (gh#xournalpp/xournalpp#2002).
  * Added a --version command to print the Xournal++ version
  * Added a libgtk version display to the About dialog
  * Added a 16kHz sample rate to audio settings and fixed the 91kHz
    sample rate (gh#xournalpp/xournalpp#2092).
  * Added file version check for future compatibility
    (gh#xournalpp/xournalpp#1991).
  * Changed wording of new page template dialog to be less
    confusing (gh#xournalpp/xournalpp#1524).
  * Fixed behavior of "Attach file to the journal" option when
    choosing "Annotate PDF" (#1725, #2106). This now allows the
    background PDF and the annotation files to be renamed and moved
    as long as they 1) share the same file prefix; and 2) share the
    same relative path.
  * Fixed an issue where clicking the X on the replace file dialog
    would overwrite the file (gh#xournalpp/xournalpp#1983).
  * (libcairo >= 1.16 only): Fixed PDF export crashing when the
    table of contents is empty (gh#xournalpp/xournalpp#2236)..
  * Fixed a bug where the PDF background would not update when
    loading a new document (gh#xournalpp/xournalpp#1964).
  * Fixed plugin window causing a crash on Ubuntu 16.04
  * Fixed a bug where the icon would not appear correctly on some
    desktop environments (gh#xournalpp/xournalpp#1892).
  * Fixed inconsistent ordering of button keybindings
    (gh#xournalpp/xournalpp#1961).
  * Fixed the Enter key not confirming PDF export settings
    (gh#xournalpp/xournalpp#1977).
  * Fixed exported PDF title (gh#xournalpp/xournalpp#2039).
  * Fixed a bug where different page backgrounds can cause PDFs to
    be exported with the wrong backgrounds
    (gh#xournalpp/xournalpp#2119).
  * Fixed a bug where the page number count would not be updated
    after deleting a page (gh#xournalpp/xournalpp#2134).
  * Fixed selection object tool not working correctly
    (gh#xournalpp/xournalpp#2081). / crashing
    (gh#xournalpp/xournalpp#2133). when there are multiple layers
- Drop xournalpp-fix-exporting-pdf-with-references.patch:
  incorporated upstream.
* Sat Sep 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add xournalpp-fix-exporting-pdf-with-references.patch: Fix PDF
  export when references exist in the document
  [gh#xournalpp/xournalpp#2236].
* Thu Jul 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add Recommends tex(standalone.tex) instead of Requires:
  texlive-latex-bin, so that users can uninstall texlive packages
  should they not use this particular feature. The standalone pkg
  is required for the feature to work and it pulls in the right
  texlive dependencies as Recommends.
* Sun Apr 26 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.18:
  * Fixed a crash occurring when recent file entries are invalid
    (gh#xournalpp/xournalpp#1730)
  * Fixed translations not being built correctly, causing
    packaging issues (gh#xournalpp/xournalpp#1596)
  * Fixed background PDF outlines not being saved in exported PDF
    (only available when compiled with Cairo 1.16 or newer)
  * Fixed a deadlock occurring when a second PDF with an outline
    is opened (gh#xournalpp/xournalpp#1582).
  * Fixed the settings file being written to when it is parsed
    (gh#xournalpp/xournalpp#1074)
  * Fixed dark mode icons not loading properly
    (gh#xournalpp/xournalpp#1767)
  * Added missing dark mode icons (gh#xournalpp/xournalpp#1765)
  * Fixed crash in Export As ... on some page range options
    (gh#xournalpp/xournalpp#1790)
  * Fixed crash caused by custom colors in toolbar being "too
    close" (gh#xournalpp/xournalpp#1659)
- No longer need to build translations independently after
  running make.
* Wed Feb 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.17:
  - Fixed arrow tip scaling: now scales with thickness instead of
    length (gh#xournalpp/xournalpp#967).
  - Changed coordinate draw direction.
  - Fixed audio playback failures not showing error messages to
    the user (gh#xournalpp/xournalpp#1573).
  - Fixed text tool bold shortcut not working when capslock is
    enabled (gh#xournalpp/xournalpp#1583).
  - Fixed sidebar preview context menu "Move Page Up" and "Move
    Page Down" buttons not being disabled on the first and last
    page, respectively (gh#xournalpp/xournalpp#1637).
  - Fixed Enter keypress on the "Goto Page" (Ctrl-G) dialog not
    changing the page (gh#xournalpp/xournalpp#975).
  - Fixed missing Xournal++ icon errors on most of the dialog
    windows (gh#xournalpp/xournalpp#1667).
- Build translations during make stage.
- Use %%cmake_build instead of obsolete %%make_jobs.
* Tue Dec 17 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.16:
  * Fixed currently editing textboxes not exporting to PDF.
  * Fixed line tool breaking when snap-to-grid is disabled.
- Changes from version 1.0.15 and 1.0.14:
  * Fixed an issue where copying and pasting strokes would crash
    the program.
  * Text field bugfixes
  * Latex tool enhancements
  * Image tool bugfixes
  * Misc quality-of-life enhancements
  * New experimental floating toolbox
  * Improved input handling, bugfixes
  * Updated preferences window
  * Fixed some crashing issues
  * Refactoring and other non-user visible changes
  * Other misc features and bugfixes
- Add xournalpp-fix-desktop-categories.patch: Fix desktop
  categories with additional keywords to prevent "No sufficient
  Category definition" error from brp-desktop.
* Sat Jun 15 2019 aloisio@gmx.com
- Update to version 1.0.12
  * Added new experimental input system that should fix a lot of
    issues related to input handling (can be enabled from
    Preferences > Input System).
  * Added experimental stroke filter (can be enabled in
    Preferences > Drawing Area) to allow selections using drawing
    tool
  * Added ability to double click on selected objects (e.g. text
    fields and LaTeX) to begin editing them (only available with
    the new input system enabled)
  * Fixed some issues with selections
  * Fixed some issues involving autosaving
  * Improved LaTeX editor experience, as well as bug fixes
  * Fixed text editor copying and pasting to the wrong clipboard
  * Fixed many zoom issues while in presentation mode
  * Fixed some other miscellaneous issues
- Use package name in the tarball
* Wed Apr 17 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.10:
  * Support for a new, future file format.
  * Lots of bug fixes and improvements.
- Drop xournalpp-fix-horizontal-space.patch: incorporated
  upstream.
- New BuildRequires: pkgconfig(libzip).
* Tue Feb 19 2019 badshah400@gmail.com
- Update to version 1.0.8:
  * Audio recording directly integrated, no VLC etc. needed.
  * LaTex use now vector graphics.
  * Multiple page layout.
  * Minor bug fixes.
- Add xournalpp-fix-horizontal-space.patch: fix adding horizontal
  space to document view from preferences; patch taken from
  upstream commit (gh#xournalpp/xournalpp#906).
- New upstream build dependencies: pkgconfig(portaudiocpp),
  pkgconfig(sndfile).
* Mon Jan 28 2019 Atri Bhattacharya <badshah400@gmail.com>
- Drop unnecessary Requires(pre/post) on desktop-file-utils.
* Thu Jan 24 2019 Jan Engelhardt <jengelh@inai.de>
- Remove future goals.
* Mon Jan 21 2019 badshah400@gmail.com
- Update to version 1.0.7:
  * Fixes for HiDPI (gh#xournalpp/xournalpp#172).
  * Drop bundled mathtex, thereby fixing a licensing issue
    (mathtex is licensed under GPL-3.0,
    gh#xournalpp/xournalpp#771).
  * Other minor bug fixes.
* Sun Dec 30 2018 badshah400@gmail.com
- Initial package (version 1.0.5).
